// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, Inc., 51 Franklin Street, Fifth
// Floor, Boston, MA 02110-1301, USA.
#include "tupmachine.h"

TupMachine::TupMachine()
{}

TupMachine::~TupMachine()
{}


/**
 * Returns the machine system name and description
 *
 */
QString TupMachine::getSysInfo()
{
  sigar_t *sigar;
  sigar_sys_info_t sysinfo;

  sigar_open(&sigar);
  sigar_sys_info_get(sigar, &sysinfo);
  sigar_close(sigar);

  return QString(sysinfo.name) + "+"
    + QString(sysinfo.version) + "+("
    + QString(sysinfo.arch) + ")";
}

QString TupMachine::getSysInfoDistribution()
{
  sigar_t *sigar;
  sigar_sys_info_t sysinfo;

  sigar_open(&sigar);
  sigar_sys_info_get(sigar, &sysinfo);
  sigar_close(sigar);

  return QString(sysinfo.vendor);
}

QString TupMachine::getSysInfoDescription()
{
  sigar_t *sigar;
  sigar_sys_info_t sysinfo;

  sigar_open(&sigar);
  sigar_sys_info_get(sigar, &sysinfo);
  sigar_close(sigar);

  return QString(sysinfo.description);
}

// /**
//  * Displays the system version into the main window.
//  * WINDOWS ONLY!!!
//  * PUT THIS IN A PLATFORM SPECIFIC FILE OR IT WON'T COMPILE
//  *
//  */
// void Tup::displayVersion()
// {
//   sigar_t *sigar;
//   sigar_version_t *version;

//   sigar_open(&sigar);
//   version = sigar_version_get();
//   sigar_close(sigar);
//   UptimeInfoOSLabelEdit->setText(tr("%1 %2 %3 %4 %5")
// 				 .arg(version->version)
// 				 .arg(version->major)
// 				 .arg(version->minor)
// 				 .arg(version->maint)
// 				 .arg(version->build));
// }

/**
 * Returns in seconds the uptime of the machine
 *
 */
double TupMachine::getUptime()
{
  /// Create sigar object
  sigar_t *sigar;
  sigar_uptime_t sigaruptime;
  /// Open it
  sigar_open(&sigar);
  /// Get the uptime
  sigar_uptime_get(sigar, &sigaruptime);
  sigar_close(sigar);
  return sigaruptime.uptime;
}

QString TupMachine::getMacAddress()
{
  QNetworkInterface interface;
  QList<QNetworkInterface> interfacesList;
  QString macAddress;

  interfacesList =  interface.allInterfaces();
  foreach(const QNetworkInterface &interface,
	  QNetworkInterface::allInterfaces())
    {
      if (interface.isValid() &&
	  !(interface.flags() & QNetworkInterface::IsLoopBack) &&
	  !(interface.hardwareAddress().isEmpty()) &&
	  interface.flags() &
          (QNetworkInterface::IsUp | QNetworkInterface::IsRunning))
	{
	  macAddress = interface.hardwareAddress();
	  break;
	}
    }
  return macAddress;
}

QString TupMachine::getMd5MacAddress()
{
  return QCryptographicHash::hash(getMacAddress()
				  .remove(QChar(':')).toLower().toAscii(),
				  QCryptographicHash::Md5).toHex();
}
